Module syntax

Module syntax 

Syntax tree definitions with change metadata.

Structs

MatchedPos
SyntaxInfo
Fields that are common to both Syntax::List and Syntax::Atom.

Enums

AtomKind
MatchKind
A matched token (an atom, a delimiter, or a comment word).
StringKind
Different types of strings. We want to diff these the same way, but highlight them differently.
Syntax
TokenKind
Unlike atoms, tokens can be delimiters like {.

Functions

change_positions
Walk nodes and return a vec of all the changed positions.
comment_positions
init_all_info
Initialise all the fields in SyntaxInfo.
init_next_prev
zip_pad_shorter
zip_repeat_shorter
Zip lhs with rhs, but repeat the last item from the shorter slice.

Type Aliases

SyntaxId